/*
	MyHelloWindow.cpp
	Dan Parks Sydow
	1997
	
	Based on source code from:
	HelloWindow.cpp
	Copyright 1995 Be Incorporated, All Rights Reserved.
*/

#ifndef _APPLICATION_H
#include <Application.h>
#endif
#ifndef MY_HELLO_WINDOW_H
#include "MyHelloWindow.h"
#endif

#define   MENU_BAR_HEIGHT   18.0


BRect       buttonBeepRect(15.0, 155.0, 110.0, 185.0);
const char* buttonBeepName = "Beep";
const char* buttonBeepLabel = "Beep";


MyHelloWindow::MyHelloWindow(BRect frame)
    : BWindow(frame, "My Hello", B_TITLED_WINDOW, B_NOT_ZOOMABLE)
{
	frame.Set(130.0, MENU_BAR_HEIGHT + 10.0, 290.0, 190.0);
    fMyView = new MyDrawView(frame, "MyDrawView");
    AddChild(fMyView);

	fButtonBeep = new BButton(buttonBeepRect, buttonBeepName, 
							   buttonBeepLabel, new BMessage(BUTTON_BEEP_MSG));
	AddChild(fButtonBeep);
    fButtonBeep->MakeDefault(true);

	BMenu		 *menu;
	BMenuItem	 *menuItem;
	BRect		 menuBarRect;
    
 	menuBarRect.Set(0.0, 0.0, 32000.0, MENU_BAR_HEIGHT);
	fMenuBar = new BMenuBar(menuBarRect, "MenuBar");
	AddChild(fMenuBar);
	
	menu = new BMenu("Audio");
	fMenuBar->AddItem(menu);
	menu->AddItem(new BMenuItem("Beep Once", new BMessage(MENU_BEEP_1_MSG)));
	menu->AddItem(menuItem = new BMenuItem("Beep Twice", new BMessage(MENU_BEEP_2_MSG)));

	menu->SetRadioMode(true);
    menuItem->SetMarked(true);
	fNumBeeps = 2;

	// **** moved the adding of menu bar to the window here, from after the set up of
	// the second menu. Now that the second menu is in its own menu bar, its code can
	// follow this call:


	// *** NEW  in P04 I add the second menu here.
	//     Now, I'm adding the same menu as a pop-up rather than in the main menu bar
	// *** NEW BMenuField object declaration:
    BMenuField  *menuField;
//    BPopUpMenu  *popUpMenu;
    BMenu  *popUpMenu;
    BRect       popUpMenuRect(10.0, 40.0, 125.0, 70.0);
    const char  *popUpName = "VisualPopUp";
    const char  *popUpLabel = "Drawing:";
//    const char  *popUpLabel = NULL;
    
    // point out that the pop up menu itself is a BMenu, and the items in the menu are
    // BMenuItems -- just as for a menu that's in the main menu bar. The first three lines
    // here are the same as in the P04 example:
//	popUpMenu = new BPopUpMenu("Visual");
	popUpMenu = new BMenu("Visual");
	// The difference comes in adding the menu to a BMenuField object rather than to
	// a BMenuBar object. In a sense you are adding the menu to a BMenuBar, though -- 
	// the BMenuField "employs a BMenuBar object to control a BMenu" (from Be Book).
	menuField = new BMenuField(popUpMenuRect, popUpName, popUpLabel, popUpMenu);
	// Add the menu field to the window as you would a main menu bar:
	AddChild(menuField);
	popUpMenu->AddItem(new BMenuItem("Draw Circles", new BMessage(MENU_DRAW_CIRCLES_MSG)));
	popUpMenu->AddItem(new BMenuItem("Draw Squares", new BMessage(MENU_DRAW_SQUARES_MSG)));
	
	// *** Here, if the menu wasn't proportioned as desired, here you could add a 
	// call to SetDivider():
//	    float  xCoordinate = 40;
//	    menuField->SetDivider(xCoordinate);
	
	// ***** NEW  not adding to the main menu bar, so cut this next line:
//	fMenuBar->AddItem(menu);
   	// *** NEW end of pop-up menu
   	
    Show();

// NOTE:  Here's another menu topic to cover. After this example, have another
//        example that stores the menu bar as a window data member.
//        The FontChart example program stores fMenuBar data member in the window 
//        class, then uses it to enable/disable a menu item at any time 
//        (using FindItem())

}


bool MyHelloWindow::QuitRequested()
{
    be_app->PostMessage(B_QUIT_REQUESTED);

    return(true);
}


void MyHelloWindow::MessageReceived(BMessage* message)
{

	switch(message->what)
	{
		case BUTTON_BEEP_MSG:
    		bigtime_t  microseconds = 1000000;  // one second
			int32      i;
			
			for (i = 1; i <= fNumBeeps; i++) 
			{
		  	   beep();
		  	   if (i != fNumBeeps)
   			      snooze(microseconds);
   			}
 		  	break;

		case MENU_BEEP_1_MSG:
		  	fNumBeeps = 1;
		  	break;

		case MENU_BEEP_2_MSG:
		  	fNumBeeps = 2;
		  	break;

		// *** NEW  menu item for second menu
		case MENU_DRAW_CIRCLES_MSG:
    		fMyView->SetViewPicture(PICTURE_CIRCLES);
    		fMyView->Invalidate();
		  	break;

		// *** NEW  menu item for second menu
		case MENU_DRAW_SQUARES_MSG:
    		fMyView->SetViewPicture(PICTURE_SQUARES);
    		fMyView->Invalidate();
		  	break;
				  	
		default:
			BWindow::MessageReceived(message);
	}
}
